@@ -14,7 +14,7 @@ sub valid_values {
         index        => [ 0, 1 ],
         alignment    => [ 0, 1, 2 ],
         layout       => [ 0, 1, 2, 3 ],
-        mouse        => [ 0, 1, 2, 3, 4 ],
+        mouse        => [ 0, 1 ],
         order        => [ 0, 1 ],
         page         => [ 0, 1 ],
 
@@ -68,7 +68,7 @@ sub invalid_values {
         index        => [ grep { ! /^[ 0 1 ]\z/x }         @invalid ],
         alignment    => [ grep { ! /^[ 0 1 2 ]\z/x }       @invalid ],
         layout       => [ grep { ! /^[ 0 1 2 3 ]\z/x }     @invalid ],
-        mouse        => [ grep { ! /^[ 0 1 2 3 4 ]\z/x }   @invalid ],
+        mouse        => [ grep { ! /^[ 0 1 ]\z/x }         @invalid ],
         order        => [ grep { ! /^[ 0 1 ]\z/x }         @invalid ],
         page         => [ grep { ! /^[ 0 1 ]\z/x }         @invalid ],
         keep         => [ grep { ! /^[ 1-9 ][ 0-9 ]*\z/x } @invalid ],
